/**
 * Interface for cache implementations.
 * Provides standard methods for interacting with a cache store.
 * All operations are asynchronous and return Promises.
 */
export interface CacheInterface {
    /**
     * Sets a value in the cache for a given key.
     *
     * @template TypeValue The type of value being stored
     * @param {string} key - The key under which to store the value
     * @param {TypeValue} value - The value to store
     * @param {number} [expiresAfter] - Optional TTL in seconds
     * @returns {Promise<boolean>} True if set successfully, false otherwise
     */
    set<TypeValue = string>(key: string, value: TypeValue, expiresAfter?: number): Promise<boolean>;
    /**
     * Retrieves a value from the cache by its key.
     *
     * @template TypeValue The expected type of the stored value
     * @param {string} key - The key of the entry to retrieve
     * @returns {Promise<TypeValue | undefined>} The stored value, or undefined if not found
     */
    get<TypeValue = string>(key: string): Promise<TypeValue | undefined>;
    /**
     * Deletes an entry from the cache.
     *
     * @param {string} key - The key of the entry to delete
     * @returns {Promise<boolean>} True if deleted successfully, false if key didn't exist
     */
    delete(key: string): Promise<boolean>;
    /**
     * Checks if a key exists in the cache.
     *
     * @param {string} key - The key to check
     * @returns {Promise<boolean>} True if the key exists, false otherwise
     */
    has(key: string): Promise<boolean>;
}
